echo "Putting 127.0.0.1 in /etc/tcp.smtp.cdb to allow qmail to send non-local mail"
echo "Edit and follow instructions in /etc/tcp.smtp if you need to change this"
tcprules /etc/tcp.smtp.cdb /etc/tcp.smtp.tmp < /etc/tcp.smtp
